.. This file is automatically generated.
    Do not edit manually.
    If you want to add to add yourself to the list of authors,
    please edit CITATION.cff and run maint_tools/citation_cff_maint.py.


.. _Ahmad Chamma: https://github.com/achamma723

.. _Aina Frau-Pascual: https://github.com/ainafp

.. _Alex Rothberg: https://github.com/cancan101

.. _Alexandre Abadie: https://github.com/aabadie

.. _Alexandre Abraham: https://twinee.fr/

.. _Alexandre Gramfort: http://alexandre.gramfort.net/

.. _Alexandre Savio: https://github.com/alex-savio

.. _Alexandre Cionca: https://github.com/acionca

.. _Alexandre Sayal: https://github.com/alexsayal

.. _Alexis Thual: https://github.com/alexisthual

.. _Alisha Kodibagkar: https://github.com/alishakodibagkar/


.. _Ana Luisa Pinho: https://github.com/alpinho

.. _Anand Joshi: https://github.com/ajoshiusc

.. _Andrés Hoyos Idrobo: https://github.com/ahoyosid

.. _Anne-Sophie Kieslinger: https://github.com/askieslinger

.. _Anupriya Kumari: https://github.com/anupriyakkumari

.. _Ariel Rokem: https://arokem.org/

.. _Arthur Mensch: https://github.com/arthurmensch

.. _Aswin Vijayan: https://github.com/vaswin0

.. _Audrey Duran: https://github.com/AudreyDuran

.. _Ben Cipollini: https://github.com/bcipolli

.. _Bertrand Thirion: https://pages.saclay.inria.fr/bertrand.thirion/

.. _Binh Nguyen: https://tbng.github.io/

.. _Caglar Cakan: https://github.com/caglorithm

.. _Chris Gorgolewski: https://chrisgorgolewski.org/

.. _Chris Markiewicz: https://github.com/effigies

.. _Christian Horea: https://chymera.eu/

.. _Christian Gerloff: https://github.com/ChristianGerloff

.. _Christina Roßmanith: https://github.com/crossmanith

.. _Colin Reininger: https://github.com/reiningc

.. _Connor Lane: https://github.com/clane9

.. _Czarina Sy: https://github.com/czarinasy

.. _Céline Delettre: https://github.com/celinede

.. _Dan Gale: https://github.com/danjgale

.. _Daniel Gomez: https://github.com/dangom

.. _Danilo Bzdok: https://github.com/banilo

.. _David G Ellis: https://github.com/ellisdg

.. _Demian Wassermann: https://github.com/demianw

.. _Derek Pisner: https://github.com/dPys

.. _Dimitri Papadopoulos Orfanos: https://github.com/DimitriPapadopoulos

.. _Elizabeth DuPre: https://elizabeth-dupre.com/

.. _Elvis Dohmatob: https://dohmatob.github.io/

.. _Eric Larson: https://larsoner.com/

.. _Evan Edmond: https://evan.science/

.. _Fabian Pedregosa: https://github.com/fabianp

.. _Florent Pollet: https://florian6973.github.io/

.. _Franz Liem: https://github.com/fliem

.. _François Paugam: https://github.com/FrancoisPgm

.. _Gael Varoquaux: https://gael-varoquaux.info/

.. _Gilles de Hollander: https://github.com/Gilles86

.. _Greg Kiar: https://gkiar.me/

.. _Greydon Gilmore: https://www.greydongilmore.com/

.. _Guillaume Lemaitre: https://glemaitre.github.io/

.. _Gustav Magnusson: https://github.com/gurraburra

.. _Hande Gözükan: https://github.com/hndgzkn

.. _Hao-Ting Wang: https://wanghaoting.com/

.. _Himanshu Aggarwal: https://github.com/man-shu

.. _Ian Abenes: https://github.com/boredStats

.. _Idrissa Traore: https://github.com/badrinini

.. _Jake Vogel: https://github.com/illdopejake

.. _Jan Margeta: https://github.com/jmargeta

.. _Jaques Grobler: https://github.com/jaquesgrobler

.. _Jason Gors: http://jgors.com/

.. _Jason Kai: https://github.com/kaitj

.. _Javier Rasero: https://jrasero.github.io/

.. _Jean Kossaifi: https://jeankossaifi.com/

.. _Jean-Rémi King: https://github.com/kingjr

.. _Jelle Roelof Dalenberg: https://github.com/jrdalenberg

.. _Jeremy Lefort-Besnard: https://jlefortbesnard.github.io/

.. _Jerome Dockes: https://jeromedockes.github.io/

.. _Jerome-Alexis Chevalier: https://github.com/ja-che

.. _Johannes Wiesner: https://github.com/JohannesWiesner

.. _John T. Johnson: https://github.com/JohnAtl

.. _Jon Haitz Legarreta Gorrono: https://github.com/jhlegarreta

.. _Jona Sassenhagen: https://github.com/jona-sassenhagen

.. _Jordi Huguet: https://github.com/jhuguetn

.. _Joshua Teves: https://github.com/jbteves

.. _Julia Huntenburg: https://github.com/juhuntenburg

.. _Julio A Peraza: https://github.com/JulioAPeraza

.. _Kamalakar Reddy Daddy: https://github.com/KamalakerDadi

.. _Kevin Sitek: https://github.com/sitek

.. _Koen Helwegen: https://github.com/koenhelwegen

.. _Konrad Wagstyl: https://github.com/kwagstyl

.. _Konstantin Shmelkov: https://github.com/kshmelkov

.. _Kshitij Chawla: https://github.com/kchawla-pi

.. _Kun CHEN: https://chenkun.me

.. _Lee Newberg: https://github.com/Leengit

.. _Leonard Sasse: https://github.com/LeSasse

.. _Loic Estève: https://github.com/lesteve

.. _Loic Tetrel: https://ltetrel.github.io/

.. _Luz Paz: https://github.com/luzpaz

.. _Manon Pietrantoni: https://github.com/ManonP38

.. _Martin Perez-Guevara: https://github.com/MartinPerez

.. _Martin Wegrzyn: https://github.com/mwegrzyn

.. _Mathias Goncalves: https://github.com/mgxd

.. _Mathieu Dugré: https://mathdugre.me

.. _Matthias Ekman: https://github.com/mekman

.. _Matthieu Joulot: https://github.com/MatthieuJoulot

.. _Maximilian Cosmo Sitter: https://github.com/mcsitter

.. _Mehdi Rahim: https://github.com/mrahim

.. _Mia Zwally: https://github.com/MIZwally

.. _Micha Burkhardt: https://github.com/mibur1

.. _Michael Eickenberg: https://github.com/eickenberg

.. _Michael Hanke: https://github.com/mih

.. _Michael Notter: https://github.com/miykael

.. _Michael Waskom: https://mwaskom.github.io/

.. _Michelle Wang: https://michellewang.github.io

.. _Mohammad Torabi: https://github.com/mtorabi59

.. _Moritz Boos: https://github.com/mjboos

.. _Mudassir Chapra: https://github.com/muddi900

.. _Myeong Seop Song: https://github.com/NeuroVR-Song

.. _Natasha Clarke: https://github.com/clarkenj

.. _Neelay Shah: https://github.com/NeelayS

.. _Nicolas Gensollen: https://nicolasgensollen.github.io/

.. _Nikhil Krish: https://github.com/NIkhilgKrish

.. _Oliver Warrington: https://github.com/OliverWarrington

.. _Oscar Esteban: https://github.com/oesteban

.. _Patrick Sadil: https://psadil.github.io/psadil

.. _Paul Bogdan: https://github.com/paulcbogdan

.. _Paul Reiners: https://github.com/paul-reiners

.. _Paula Sanz-Leon: https://github.com/pausz

.. _Peer Herholz: https://peerherholz.github.io/

.. _Philippe Gervais: https://github.com/pgervais

.. _Pierre Bellec: https://github.com/lunebellec

.. _Pierre Glaser: https://pierreglaser.github.io/

.. _Pierre-Louis Barbarant: https://github.com/pbarbarant

.. _Pierre-Olivier Quirion: https://github.com/poquirion

.. _Pradeep Reddy Raamana: https://github.com/raamana

.. _Prakhar Jain: https://github.com/PrakharJain1509

.. _Rahul Brito: https://github.com/Rahul-Brito

.. _Raphael Meudec: https://github.com/RaphaelMeudec

.. _Robert Luke: https://github.com/rob-luke

.. _Robert Williamson: https://github.com/RobWilliamson15

.. _Roberto Guidotti: https://github.com/robbisg

.. _Rohan Thomas Jepegnanam: https://github.com/rohan3412

.. _Ronald Phlypo: https://github.com/rphlypo

.. _Ryan Hammonds: https://github.com/ryanhammonds

.. _Rémi Gau: https://github.com/Remi-Gau

.. _Sachin Patalasingh: https://github.com/sachin-bsai

.. _Sage Hahn: https://github.com/sahahn

.. _Salma Bougacha: https://github.com/salma1601

.. _Sam Buck Johnson: https://github.com/sambjohnson

.. _Sami Jawhar: https://github.com/sjawhar

.. _Simon Steinkamp: https://github.com/SRSteinkamp

.. _Sin Kim: https://github.com/kimsin98

.. _Sourav Singh: https://github.com/souravsingh

.. _Steven Meisler: https://www.stevenmeisler.com

.. _Suramya Pokharel: https://github.com/SuramyaP

.. _Sylvain Lan: https://github.com/SylvainLan

.. _Sylvain Takerkart: https://github.com/SylvainTakerkart

.. _Tamer Gezici: https://github.com/TamerGezici

.. _Tarun Samanta: https://github.com/SamantaTarun

.. _Taylor Salo: https://tsalo.github.io/

.. _Tharun K: https://github.com/tharun634

.. _Thiti Premrudeepreechacharn: https://tpremrud.github.io/

.. _Thomas Bazeille: https://github.com/thomasbazeille

.. _Tom Vanasse: https://github.com/tvanasse

.. _Vasco Diogo: https://github.com/vascosa

.. _Victoria Shevchenko: https://github.com/victoris93

.. _Vincent Michel: https://github.com/vmichel

.. _Virgile Fritsch: https://github.com/VirgileFritsch

.. _Yaroslav Halchenko: https://github.com/yarikoptic

.. _Yasmin Mzayek: https://github.com/ymzayek

.. _Yichun Huang: https://github.com/YCHuang0610

.. _Zvi Baratz: https://github.com/ZviBaratz

.. _Óscar Nájera: https://github.com/Titan-C
